@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-OpenSsh
 #
-# This software is Copyright (c) 2008-2019 by Dominique Dumont.
+# This software is Copyright (c) 2008-2021 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -54,6 +54,10 @@ sub parse_html_man_page ($html_man_page) {
     my $ssh_data = sub {
         my $text = $_->text();
         $text =~ s/([\w-]+)\((\d+)\)/L<$1($2)>/g;
+        # replace utf-8 quotes with B<>
+        $text =~ s/\x{201c}(\w+)\x{201d}/B<$1>/g;
+        # replace single utf-8 quote with ascii quote
+        $text =~ s/\x{2019}/'/g;
         push $data{element_data}{$parameter}->@*, $text if $parameter;
     };
 
@@ -89,7 +93,7 @@ sub setup_choice {
     );
 }
 
-my $ssh_host = 'type=hash index_type=string cargo type=node '
+my $ssh_host = 'type=hash index_type=string ordered=1 cargo type=node '
     .'config_class_name=Ssh::HostElement';
 my $ssh_forward = 'type=list cargo type=node config_class_name="Ssh::PortForward"';
 my $uniline = 'type=leaf value_type=uniline';
